Method: RC::Interface#profile_names

Defined in:
lib/rc/interface.rb

#profile_names(tool = nil, opts = {}) ⇒ Object

Return a list of names of defined profiles for a given tool.

Examples:

profile_names(:qed)

Parameters:

  • tool (#to_sym) (defaults to: nil)

    Tool for which lookup defined profiles. If none given the current tool is used.

  • opts (Hash) (defaults to: {})

    Options for looking up profiles.

Options Hash (opts):

  • :gem (#to_s)

    Name of library from which to load the configuration.



94
95
96
97
98
99
100
101
102
103
# File 'lib/rc/interface.rb', line 94

def profile_names(tool=nil, opts={})
  if Hash === tool
    opts, tool = tool, nil
  end

  tool = tool || current_tool
  gem  = opts[:from]

  configuration(gem).profile_names(tool)
end