Method: RC::Interface#properties
- Defined in:
- lib/rc/interface.rb
#properties ⇒ Object
Properties of the current project. These can be used in a project’s config file to make configuration more interchangeable. Presently project properties are gathered from .index YAML or .gemspec.
It’s important to note that properties are not per-gem. Rather they are global and belong only the current project.
151 152 153 |
# File 'lib/rc/interface.rb', line 151 def properties $properties ||= Properties.new end |